<?php
namespace Elementor;

class ride_sharing_affiliate_forms_widget extends Widget_Base {
	
	public function get_name() {
		return 'ride-sharing-affiliate-forms';
	}
	
	public function get_title() {
		return esc_html__('Ride Sharing Affiliate Forms','ride-sharing');
	}
	
	public function get_icon() {
		return 'fab fa-elementor';
	}
	
	public function get_categories() {
		return [ 'ride-sharing-affiliate-widgets' ];
	}
	
	protected function register_controls() {

		$this->start_controls_section(
			'section_title',
			[
				'label' => esc_html__( 'General Options', 'ride-sharing' ),
			]
		);
		
		$this->add_control(
			'affiliate_form_action_url',
			[
				'label' => esc_html__( 'Form Action url', 'ride-sharing' ),
				'label_block' => true,
				'type' => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Example: https://www.blablacar.ro/search?', 'ride-sharing' ),
			]
		);

		$this->add_control(
			'submit_button_label',
			[
				'label' => esc_html__( 'Submit Button label', 'ride-sharing' ),
				'label_block' => true,
				'type' => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter Submit button label', 'ride-sharing' ),
			]
		);

		$this->add_control(
			'color',
			[
				'type' => \Elementor\Controls_Manager::COLOR,
				'label' => esc_html__( 'Choose custom background color', 'ride-sharing' ),
			]
		);

		$repeater = new Repeater();
		$repeater->add_control(
			'field',
			[
				'label' => esc_html__( 'Field Type', 'ride-sharing' ),
				'label_block' => true,
				'type' => Controls_Manager::SELECT,
				'options' => [
					'input_text' 	=> esc_html__( 'Input text', 'ride-sharing' ),
					'input_number' 	=> esc_html__( 'Input number', 'ride-sharing' ),
					'input_hidden' 	=> esc_html__( 'Input hidden', 'ride-sharing' ),
					'input_datepicker' 	=> esc_html__( 'Input datepicker', 'ride-sharing' ),
					'textarea' 	=> esc_html__( 'Textarea', 'ride-sharing' ),
				]
			]
		);
		$repeater->add_control(
	    'label',
	        [
	            'label' => esc_html__('Label', 'ride-sharing'),
	            'type' => Controls_Manager::TEXT,
	            'description ' => esc_html__('Placeholder for the current field: Eg: "Where You From"', 'ride-sharing'),
	        ]
	    );
	    $repeater->add_control(
	    'placeholder',
	        [
	            'label' => esc_html__('Placeholder', 'ride-sharing'),
	            'type' => Controls_Manager::TEXT,
	            'description ' => esc_html__('Placeholder for the current field: Eg: "Departure"', 'ride-sharing'),
	        ]
	    );
	    $repeater->add_control(
	    'name',
	        [
	            'label' => esc_html__('Name', 'ride-sharing'),
	            'type' => Controls_Manager::TEXT,
	            'description ' => esc_html__('Placeholder for the current field: Eg: "departure"', 'ride-sharing'),
	        ]
	    );
	    $repeater->add_control(
	    'value',
	        [
	            'label' => esc_html__('Value', 'ride-sharing'),
	            'type' => Controls_Manager::TEXT,
	            'description ' => esc_html__('Placeholder for the current field: Eg: "Bucharest"', 'ride-sharing'),
	        ]
	    );
	    $repeater->add_control(
	    'date_format',
	        [
	            'label' => esc_html__('Date Format', 'ride-sharing'),
	            'type' => Controls_Manager::TEXT,
	            'description ' => esc_html__('Set a date format (Read more at: <a target="_blank" href="https://jqueryui.com/datepicker/#date-formats">Date formats docs</a>)', 'ride-sharing'),
	            'condition' => [
                    'field' => 'input_datepicker',
                ],
	        ]
	    );
	    $repeater->add_control(
	    'required',
	        [
	            'label' => esc_html__('Required?', 'ride-sharing'),
	            'type' => Controls_Manager::SWITCHER,
	            'description ' => esc_html__('Set if the field will be required or not.', 'ride-sharing'),
	        ]
	    );
	    $this->add_control(
	        'form_fields',
	        [
	            'label' => esc_html__('Form Fields Builder', 'ride-sharing'),
	            'type' => Controls_Manager::REPEATER,
	            'fields' => $repeater->get_controls()
	        ]
	    );

		$this->end_controls_section();

	}
	
	protected function render() {
        $settings 					= $this->get_settings_for_display();
        $affiliate_form_action_url 	= $settings['affiliate_form_action_url'];
        $submit_button_label 		= $settings['submit_button_label'];
        $color 						= $settings['color'];
        $form_fields 				= $settings['form_fields'];

		$shortcode_content = '';
		$serialized_form_fields = base64_encode(serialize($form_fields));

        $shortcode_content .= do_shortcode('[ride-sharing-affiliate-shortcode page_builder="elementor" affiliate_form_action_url="'.$affiliate_form_action_url.'" color="'.$color.'" form_fields="'.$serialized_form_fields.'" submit_button_label="'.$submit_button_label.'"]');

        echo  $shortcode_content;
	}
	
	protected function content_template() {

    }
	
	
}